@@ -91,7 +91,7 @@ class Hoe
   include Rake::DSL if defined?(Rake::DSL)
 
   # duh
-  VERSION = "3.16.1"
+  VERSION = "3.17.2"
 
   @@plugins = [:clean, :debug, :deps, :flay, :flog, :newb, :package,
                :publish, :gemcutter, :signing, :test]
@@ -471,7 +471,7 @@ class Hoe
 
     case name
     when "hoe" then
-      dependency "rake", [">= 0.8", "< 11.0"]
+      dependency "rake", [">= 0.8", "< 13.0"]
     else
       version = VERSION.split(/\./).first(2).join(".")
       dependency "hoe", "~> #{version}", :development
@@ -527,7 +527,7 @@ class Hoe
                                when Array then
                                  urls.first
                                else
-                                 raise "unknown urls format: #{urls.inspect}"
+                                 warn "** Unknown urls format: #{urls.inspect}"
                                end
       s.description          = description
       s.files                = manifest
@@ -647,8 +647,8 @@ class Hoe
       self.history_file = manifest.grep(/^History\./).first
     end
 
-    self.history_file ||= Dir.glob("History.{txt,md}").first
-    self.readme_file  ||= Dir.glob("README.{txt,md}").first
+    self.history_file ||= Dir.glob("History.{txt,md}").first || "History.txt"
+    self.readme_file  ||= Dir.glob("README.{txt,md}").first || "README.txt"
 
     abort "Hoe.new {...} removed. Switch to Hoe.spec." if block_given?
   end
